@@ -216,7 +216,7 @@ typedef enum
     LOK_CALLBACK_GRAPHIC_SELECTION = 6,
 
     /**
-     * User clicked on an hyperlink that should be handled by other
+     * User clicked on a hyperlink that should be handled by other
      * applications accordingly.
      */
     LOK_CALLBACK_HYPERLINK_CLICKED = 7,
@@ -644,10 +644,9 @@ typedef enum
      * Notification that the clipboard contents have changed.
      * Typically fired in response to copying to clipboard.
      *
-     * The payload currently is empty and it's up to the
-     * client to get the contents, if necessary. However,
-     * in the future the contents might be included for
-     * convenience.
+     * Payload is optional. When payload is empty, Online gets string from selected text.
+     * Payload format is JSON.
+     * Example: { "mimeType": "string", "content": "some content" }
      */
     LOK_CALLBACK_CLIPBOARD_CHANGED = 38,
 
@@ -752,6 +751,27 @@ typedef enum
      * }
      */
     LOK_CALLBACK_FORM_FIELD_BUTTON = 49,
+
+    /**
+     * This is Calc specific. Indicates that some or all of the current sheet's
+     * geometry data has changed. Clients must request a full or partial sheet
+     * geometry data set.
+     *
+     * The payload specifies what part of the sheet geometry data has changed.
+     * The payload format is:
+     * 'all|rows|columns [sizes [hidden [filtered [groups]]]]'
+     *
+     * For example, the payload 'rows sizes groups' indicates that the row heights
+     * and row-groups data have changed.
+     */
+    LOK_CALLBACK_INVALIDATE_SHEET_GEOMETRY = 50,
+
+    /**
+     * When for the current cell is defined an input help text.
+     *
+     * The payload format is JSON: { "title": "title text", "content": "content text" }
+     */
+    LOK_CALLBACK_VALIDITY_INPUT_HELP = 51,
 }
 LibreOfficeKitCallbackType;
 
@@ -856,6 +876,8 @@ static inline const char* lokCallbackTypeToString(int nType)
         return "LOK_CALLBACK_WINDOW";
     case LOK_CALLBACK_VALIDITY_LIST_BUTTON:
         return "LOK_CALLBACK_VALIDITY_LIST_BUTTON";
+    case LOK_CALLBACK_VALIDITY_INPUT_HELP:
+        return "LOK_CALLBACK_VALIDITY_INPUT_HELP";
     case LOK_CALLBACK_CLIPBOARD_CHANGED:
         return "LOK_CALLBACK_CLIPBOARD_CHANGED";
     case LOK_CALLBACK_CONTEXT_CHANGED:
@@ -880,6 +902,8 @@ static inline const char* lokCallbackTypeToString(int nType)
         return "LOK_CALLBACK_TAB_STOP_LIST";
     case LOK_CALLBACK_FORM_FIELD_BUTTON:
         return "LOK_CALLBACK_FORM_FIELD_BUTTON";
+    case LOK_CALLBACK_INVALIDATE_SHEET_GEOMETRY:
+        return "LOK_CALLBACK_INVALIDATE_SHEET_GEOMETRY";
     }
 
     assert(!"Unknown LibreOfficeKitCallbackType type.");
